pub fn InstallBackHandler<K: NavKey>(stack: NavBackStack<K>) -> DisposeExpand description
Install/uninstall the global back handler for the displayed stack.
pub fn InstallBackHandler<K: NavKey>(stack: NavBackStack<K>) -> DisposeInstall/uninstall the global back handler for the displayed stack.